@@ -10,6 +10,7 @@
 #include "abstractkrunnerplugin.h"
 
 #include <QDBusMessage>
+#include <QJsonArray>
 #include <QMultiHash>
 
 class TabsRunnerPlugin : public AbstractKRunnerPlugin
@@ -26,7 +27,11 @@ public:
     RemoteActions Actions() override;
     RemoteMatches Match(const QString &searchTerm) override;
     void Run(const QString &id, const QString &actionId) override;
+    void Teardown() override;
 
 private:
+    RemoteMatches match(const QString &query) const;
+
     QMultiHash<QString, QDBusMessage> m_requests;
+    QJsonArray m_tabs;
 };
